%define srcname    spatialindex
%define major      8
%define libname    %mklibname %{srcname} %{major}
%define libnamedev %mklibname %{srcname} -d

Name:           libspatialindex
Version:        2.1.0
Release:        %mkrel 2
Summary:        Spatial indexing libraries
Group:          System/Libraries
License:        MIT
Url:            https://libspatialindex.org/
Source0:        https://github.com/libspatialindex/libspatialindex/releases/download/%{version}/%{srcname}-src-%{version}.tar.bz2
# Support testing with a system/external copy of GTest
# https://github.com/libspatialindex/libspatialindex/pull/270
Patch1:         https://github.com/libspatialindex/libspatialindex/pull/270.patch
Patch2:         libspatialindex-cmake-4.0.patch
BuildRequires:  cmake
BuildRequires:  cmake(GTest)

%description
Spatial indexing libraries.

%package -n %{libname}
Summary:        Spatial indexing libraries
Group:          System/Libraries
Provides:       libspatialindex%{?_isa} = %{version}-%{release}
Provides:       libspatialindex = %{version}-%{release}

%description -n %{libname}
Spatial indexing libraries.
The purpose of this library is to provide:
- An extensible framework that will support robust spatial indexing methods.
- Support for sophisticated spatial queries. Range, point location, nearest
  neighbor and k-nearest neighbor as well as parametric queries (defined by
  spatial constraints) should be easy to deploy and run.
- Easy to use interfaces for inserting, deleting and updating information.
- Wide variety of customization capabilities. Basic index and storage
  characteristics like the page size, node capacity, minimum fan-out,
  splitting algorithm, etc. should be easy to customize.
- Index persistence. Internal memory and external memory structures should be
  supported. Clustered and non-clustered indices should be easy to be
persisted.

%package -n %{libnamedev}
Summary:        Development files for %{name}
Group:          Development/Databases
Requires:       %{libname} = %{version}-%{release}
Provides:       %{srcname}-devel = %{version}-%{release}

%description -n %{libnamedev}
Development files needed to build software using %{name}.

%prep
%autosetup -p1 -n %{srcname}-src-%{version}

%build
# GTest >=1.13 requires >=C++14
%cmake \
       -DBUILD_TESTING:BOOL=ON \
       -DSYSTEM_GTEST:BOOL=ON \
       -UINCLUDE_INSTALL_DIR -ULIB_INSTALL_DIR \
       -DCMAKE_CXX_STANDARD=17
%cmake_build

%install
%cmake_install

%files -n %{libname}
%license COPYING
%doc AUTHORS ChangeLog CITATION.cff
%{_libdir}/*.so.%{major}{,.*}

%files -n %{libnamedev}
%{_includedir}/spatialindex/
%{_libdir}/*.so
%{_libdir}/cmake/%{name}/
%{_libdir}/pkgconfig/%{name}.pc


%changelog
* Thu Jul 03 2025 aurr <aurr> 2.1.0-2.mga10
+ Revision: 2244345
- fix build with cmake-4.0

* Sat May 24 2025 daviddavid <daviddavid> 2.1.0-1.mga10
+ Revision: 2186152
- new version: 2.1.0
- now libmajor is 8

* Sat Sep 17 2022 wally <wally> 1.9.3-5.mga9
+ Revision: 1889529
- provide also non arch dependent libspatialindex with lib pkg

* Sat Sep 17 2022 wally <wally> 1.9.3-4.mga9
+ Revision: 1889525
- provide libspatialindex with lib pkg

* Thu Mar 17 2022 umeabot <umeabot> 1.9.3-3.mga9
+ Revision: 1795223
- Mageia 9 Mass Rebuild

* Mon Feb 17 2020 daviddavid <daviddavid> 1.9.3-2.mga8
+ Revision: 1537141
- use new cmake macros
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Fri Oct 25 2019 daviddavid <daviddavid> 1.9.3-1.mga8
+ Revision: 1455696
- new version: 1.9.3

* Wed Oct 23 2019 daviddavid <daviddavid> 1.9.2-1.mga8
+ Revision: 1455259
- new version: 1.9.2
- now libmajor is 6

* Sun Sep 23 2018 umeabot <umeabot> 1.8.5-3.mga7
+ Revision: 1299160
- Mageia 7 Mass Rebuild

* Thu Feb 11 2016 umeabot <umeabot> 1.8.5-2.mga6
+ Revision: 955651
- Mageia 6 Mass Rebuild

* Tue Sep 01 2015 fwang <fwang> 1.8.5-1.mga6
+ Revision: 871831
- 1.8.5

* Wed Oct 15 2014 umeabot <umeabot> 1.8.0-4.mga5
+ Revision: 747746
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.8.0-3.mga5
+ Revision: 681792
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.8.0-2.mga4
+ Revision: 522598
- Mageia 4 Mass Rebuild

* Fri Mar 22 2013 fwang <fwang> 1.8.0-1.mga3
+ Revision: 404451
- br cmake
- lock libmajor
+ obgr_seneca <obgr_seneca>
- imported package libspatialindex


* Mon Jan 14 2013 Oliver Burger <obgr_seneca@mageia.org> 1.8.0-1.mga3
- Imported package libspatialindex

